@@ -1,6 +1,5 @@
 from .controller import EventSpace
 from .eventor import ClientEvent, ServerEvent, DuplexEvent
-from .eventor import EventController, EventGroupBase, EventGroupBaseMixedIn
-from .eventor import EventGroup  # DEPRECATED
+from .eventor import EventController
 from .eventor import Namespace, SocketIO
 from .structures import EventException
